@@ -21,11 +21,10 @@ class build_py(build_py_orig):
 
 
 def artipy(dirname, setup_py):
-    opts = {
-        'ext_modules': cythonize(find_extensions(dirname, setup_py)),
-        'cmdclass': {'build_py': build_py},
-    }
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
-        return opts
+        return {
+            'ext_modules': cythonize(find_extensions(dirname, setup_py)),
+            'cmdclass': {'build_py': build_py},
+        }
